<!DOCTYPE HTML>
<html>
<head>
<title>CE Image Compatibility</title>
<style>
* {
	padding: 0;
	margin: 0;
}

html, body, div, p, span, h1, h2, h3, h4, h5, h6, img, ul, ol, dl, li, dt, dd, blockquote, pre, form, fieldset, label, table, th, td, a {
	margin: 0;
	padding: 0;
	border: 0;
	vertical-align: baseline;
	outline: none;
}

body {
	background-color: #414141;
	color: #fff;
	font-family: Arial, sans-serif;
	font-size: 13px;
}

p {
	margin-bottom: 12px;
}

ul, ol {
	list-style: none;
	margin-bottom: 12px;
	margin-left: 10px;
}

ul {
	list-style: none;
}

body {
	background-color: #f9f9f9;
}
h1 {
	font-size: 24px;
	font-weight: normal;
	color: #000;
	margin-bottom: .5em;
	text-align: center;
}

#wrapper {
	width: 500px;
	padding: 20px;
	margin: 100px auto;
	background-color: #fff;

	border: 2px solid #00a6e7;
	color: #111;
	box-shadow: 0 0 8px rgba(0,0,0,.3);
}
</style>
</head>

<body>

<div id="wrapper">
<h1>CE Image Compatibility</h1>

<?php
/*
Copyright 2011 Causing Effect - http://www.causingeffect.com - software@causingeffect.com
This software is copyrighted software. Unless you have been granted prior, written consent from Causing Effect, you may not:
- Reproduce, distribute, or transfer the Software, or portions thereof, to any third party.
- Sell, rent, lease, assign, or sublet the Software or portions thereof.
- Grant rights to any other person.
- Use the Software in violation of any United States or international law or regulation.
*/

$compatible = TRUE;
$messages = array();

//PHP version check
$version = phpversion();
if ( version_compare('5.0.0', phpversion() ) == 1 )
{
	$compatible = FALSE;
	$messages[] = "You need PHP 5+. Your current version is $version.";
}

//PHP version and cURL check for S3
if ( version_compare('5.2.0', phpversion() ) == 1 || ! function_exists( 'curl_init' ) )
{
	$message = 'You will not be able to use Amazon S3.';

	if ( version_compare('5.2.0', phpversion() ) == 1 )
	{
		$message .= 'Your version of PHP is less than 5.2.';
	}

	if ( ! function_exists( 'curl_init' ) )
	{
		 $message .= 'You do not have cURL installed.';
	}

	$messages[] = $message;
}

//cURL and allow_url_fopen check for remote images
if ( ! function_exists( 'curl_init' ) && ! function_exists('allow_url_fopen' ) )
{
	$messages[] = "You will not be able to download remote images, because both cURL and allow_url_fopen are not installed.";
}

//Is GD installed?
if ( ! extension_loaded('gd') && ! function_exists( 'gd_info' ) ) //no gd
{
	$compatible = FALSE;
	$messages[] = 'You do NOT have GD support enabled.';
}
else //gd is supported
{
	//get the GD info
	$gd_info = gd_info();

	//GD version check
	if ( substr( preg_replace( '#[^\d]#', '$1', $gd_info['GD Version']), 0, 1) < 2)
	{
		$compatible = FALSE;
		$messages[] = 'Your GD library is too old. Version 2+ is required.';
	}

	//png support
	if ( ! $gd_info['PNG Support'] )
	{
		$compatible = FALSE;
		$messages[] = 'Your GD library does not have png support.';
	}

	//gif support
	if ( ! ( $gd_info['GIF Read Support'] && $gd_info['GIF Create Support'] ) )
	{
		$compatible = FALSE;
		$messages[] = 'Your GD library does not have gif support.';
	}

	//jpg support
	if ( ! $gd_info['JPEG Support'] && ! $gd_info['JPG Support'] )
	{
		$compatible = FALSE;
		$messages[] = 'Your GD library does not have jpg support.';
	}

	$filters = array('IMG_FILTER_NEGATE','IMG_FILTER_GRAYSCALE','IMG_FILTER_BRIGHTNESS','IMG_FILTER_CONTRAST','IMG_FILTER_COLORIZE','IMG_FILTER_EDGEDETECT','IMG_FILTER_EMBOSS','IMG_FILTER_GAUSSIAN_BLUR','IMG_FILTER_SELECTIVE_BLUR','IMG_FILTER_MEAN_REMOVAL','IMG_FILTER_SMOOTH','IMG_FILTER_PIXELATE');

	foreach ( $filters as $filter )
	{
		if ( ! defined( $filter ) )
		{
			$messages[] = '<p>The ' . ucwords( strtolower( str_replace( array( 'IMG_FILTER_', '_' ), array( '', ' ' ), $filter ) ) ) . ' filter is not supported.</p>';
		}
	}
}
//safe mode check
if( ini_get('safe_mode') )
{
	$messages[] = 'CE Image may not work, or may not work as expected, because PHP Safe Mode is enabled.';
}



if ( $compatible )
{
	echo '<p><strong>Congratulations!</strong> It appears your server meets the requirements to use CE Image!</p>';

	if ( count( $messages ) >= 1 )
	{
		echo PHP_EOL . '<p>Here are some things to be aware of though:</p>' . PHP_EOL;
	}
}
else
{
	echo '<p><strong>Sorry</strong>, it appears your server does <strong>NOT</strong> meet the requirements to run CE Image. Here are the details:</p>' . PHP_EOL;
}

if ( count( $messages ) >= 1 )
{
	echo '<ul>' . PHP_EOL;
	foreach( $messages as $message)
	{
		echo '<li>' . $message . '</li>' . PHP_EOL;
	}
	echo '</ul>' . PHP_EOL;
}
?>
</div><!-- #wrapper -->
</body>
</html>